==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebFilteringExpressionsTreeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeDetailDescriptionMetadata } from "./WebFilteringExpressionsTreeDetailDescriptionMetadata";
import { WebFilteringExpressionsTreeEventArgsDescription } from "./WebFilteringExpressionsTreeEventArgsDescription";
/**
 * @hidden
 */
export let WebFilteringExpressionsTreeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringExpressionsTreeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a == null) {
                WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringExpressionsTreeEventArgsDescriptionMetadata.c(WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a);
            WebFilteringExpressionsTreeDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeEventArgs");
            a.item("Detail", "ExportedType:WebFilteringExpressionsTreeDetail");
        }
        static d(a) {
            WebFilteringExpressionsTreeEventArgsDescriptionMetadata.b(a);
            a.aa("WebFilteringExpressionsTreeEventArgs", () => new WebFilteringExpressionsTreeEventArgsDescription());
            a.z("WebFilteringExpressionsTreeEventArgs", WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a);
        }
    }
    WebFilteringExpressionsTreeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringExpressionsTreeEventArgsDescriptionMetadata, 'WebFilteringExpressionsTreeEventArgsDescriptionMetadata');
    WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebFilteringExpressionsTreeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeDetailDescriptionMetadata } from "./WebFilteringExpressionsTreeDetailDescriptionMetadata";
import { WebFilteringExpressionsTreeEventArgsDescription } from "./WebFilteringExpressionsTreeEventArgsDescription";
/**
 * @hidden
 */
export let WebFilteringExpressionsTreeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringExpressionsTreeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a == null) {
                WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringExpressionsTreeEventArgsDescriptionMetadata.c(WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a);
            WebFilteringExpressionsTreeDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeEventArgs");
            a.item("Detail", "ExportedType:WebFilteringExpressionsTreeDetail");
        }
        static d(a) {
            WebFilteringExpressionsTreeEventArgsDescriptionMetadata.b(a);
            a.ac("WebFilteringExpressionsTreeEventArgs", () => new WebFilteringExpressionsTreeEventArgsDescription());
            a.ab("WebFilteringExpressionsTreeEventArgs", WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a);
        }
    }
    WebFilteringExpressionsTreeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringExpressionsTreeEventArgsDescriptionMetadata, 'WebFilteringExpressionsTreeEventArgsDescriptionMetadata');
    WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeEventArgsDescriptionMetadata;
})();
